@@ -49,19 +49,7 @@ __PACKAGE__->meta->make_immutable();
 
 1;
 
-__END__
 
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-OpusVL::Preferences::Schema::Result::PrfDefaultValues
-
-=head1 VERSION
-
-version 0.28
 
 =head1 DESCRIPTION
 
@@ -82,21 +70,11 @@ because prf_defaults already has a default_value column.
 
 =head2 name
 
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2012 OpusVL.
 
 This software is licensed according to the "IP Assignment Schedule" provided with the development project.
 
-=head1 AUTHOR
-
-OpusVL - www.opusvl.com
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by OpusVL - www.opusvl.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
