@@ -60,19 +60,6 @@ __PACKAGE__->has_many
 
 return 1;
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-OpusVL::Preferences::Schema::Result::PrfOwnerType
-
-=head1 VERSION
-
-version 0.28
 
 =head1 DESCRIPTION
 
@@ -83,6 +70,7 @@ database that are C<PrfOwner>s.
 This appears to be entirely so that we can use numbers instead of letters
 everywhere else.
 
+
 =head1 METHODS
 
 =head1 ATTRIBUTES
@@ -97,21 +85,11 @@ everywhere else.
 
 =head2 owner_resultset
 
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2012 OpusVL.
 
 This software is licensed according to the "IP Assignment Schedule" provided with the development project.
 
-=head1 AUTHOR
-
-OpusVL - www.opusvl.com
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by OpusVL - www.opusvl.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
